==> rekonq_0.4.0.orig.tar.bz2: rekonq-0.4.0/src/tests/networkaccessmanager_test.cpp <==
/*
 * Copyright 2010 Andrea Diamantini <adjam7@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301  USA
 */



#include <qtest_kde.h>

#include <QtCore>
#include <QtGui>
#include <QtTest>

#include "networkaccessmanager.h"


class NetworkAccessManagerTest : public QObject
{
    Q_OBJECT
    
public slots:
    void initTestCase();
    void cleanupTestCase();
    
private slots:

private:
    NetworkAccessManager *manager;
};


// -------------------------------------------

void NetworkAccessManagerTest::initTestCase()
{
    manager = new NetworkAccessManager;
}


void NetworkAccessManagerTest::cleanupTestCase()
{
    delete manager;
}
    
    
// -------------------------------------------



// -------------------------------------------

QTEST_KDEMAIN(NetworkAccessManagerTest,GUI)
#include "networkaccessmanager_test.moc"

==> rekonq_0.5.0.orig.tar.bz2: rekonq-0.5.0/src/tests/networkaccessmanager_test.cpp <==
/*
 * Copyright 2010 Andrea Diamantini <adjam7@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301  USA
 */



#include <qtest_kde.h>

#include <QtCore>
#include <QtGui>
#include <QtTest>

#include "networkaccessmanager.h"


class NetworkAccessManagerTest : public QObject
{
    Q_OBJECT

public slots:
    void initTestCase();
    void cleanupTestCase();

private slots:

private:
    NetworkAccessManager *manager;
};


// -------------------------------------------

void NetworkAccessManagerTest::initTestCase()
{
    manager = new NetworkAccessManager(this);
}


void NetworkAccessManagerTest::cleanupTestCase()
{
    delete manager;
}


// -------------------------------------------



// -------------------------------------------

QTEST_KDEMAIN(NetworkAccessManagerTest, GUI)
#include "networkaccessmanager_test.moc"
